Learn R Programming

W4MRUtils (version 1.2.1)

metab_merge: Merging a dataMatrix with a metadata file

Description

metab_merge Function to merge the dataMatrix table with one of its corresponding metadata table (sampleMetadata or variableMetadata)

Usage

metab_merge(DM, meta, metype = "sample")

Value

a data.frame corresponding to a combined table with both intensities and metadata

Arguments

DM

Data.frame corresponding to the dataMatrix you want to merge with a metadata table

meta

Data.frame corresponding to the metadata table you want to merge with the dataMatrix

metype

Character string indicating the type of metadata table used; should be one between "sample" and "variable"

Author

M.Petera