metab_merge Function to merge the dataMatrix table with one of its corresponding metadata table (sampleMetadata or variableMetadata)
metab_merge(DM, meta, metype = "sample")a data.frame corresponding to a combined table with both intensities and metadata
Data.frame corresponding to the dataMatrix you want to merge with a metadata table
Data.frame corresponding to the metadata table you want to merge with the dataMatrix
Character string indicating the type of metadata table used; should be one between "sample" and "variable"
M.Petera